# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Data(object):
    """
    The payload of the event. Information within `data` comes from the resource emitting the event.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Data object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param event_grouping_id:
            The value to assign to the event_grouping_id property of this Data.
        :type event_grouping_id: str

        :param event_name:
            The value to assign to the event_name property of this Data.
        :type event_name: str

        :param compartment_id:
            The value to assign to the compartment_id property of this Data.
        :type compartment_id: str

        :param compartment_name:
            The value to assign to the compartment_name property of this Data.
        :type compartment_name: str

        :param resource_name:
            The value to assign to the resource_name property of this Data.
        :type resource_name: str

        :param resource_id:
            The value to assign to the resource_id property of this Data.
        :type resource_id: str

        :param availability_domain:
            The value to assign to the availability_domain property of this Data.
        :type availability_domain: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this Data.
        :type freeform_tags: dict(str, str)

        :param defined_tags:
            The value to assign to the defined_tags property of this Data.
        :type defined_tags: dict(str, dict(str, object))

        :param identity:
            The value to assign to the identity property of this Data.
        :type identity: oci.audit.models.Identity

        :param request:
            The value to assign to the request property of this Data.
        :type request: oci.audit.models.Request

        :param response:
            The value to assign to the response property of this Data.
        :type response: oci.audit.models.Response

        :param state_change:
            The value to assign to the state_change property of this Data.
        :type state_change: oci.audit.models.StateChange

        :param additional_details:
            The value to assign to the additional_details property of this Data.
        :type additional_details: dict(str, object)

        """
        self.swagger_types = {
            'event_grouping_id': 'str',
            'event_name': 'str',
            'compartment_id': 'str',
            'compartment_name': 'str',
            'resource_name': 'str',
            'resource_id': 'str',
            'availability_domain': 'str',
            'freeform_tags': 'dict(str, str)',
            'defined_tags': 'dict(str, dict(str, object))',
            'identity': 'Identity',
            'request': 'Request',
            'response': 'Response',
            'state_change': 'StateChange',
            'additional_details': 'dict(str, object)'
        }

        self.attribute_map = {
            'event_grouping_id': 'eventGroupingId',
            'event_name': 'eventName',
            'compartment_id': 'compartmentId',
            'compartment_name': 'compartmentName',
            'resource_name': 'resourceName',
            'resource_id': 'resourceId',
            'availability_domain': 'availabilityDomain',
            'freeform_tags': 'freeformTags',
            'defined_tags': 'definedTags',
            'identity': 'identity',
            'request': 'request',
            'response': 'response',
            'state_change': 'stateChange',
            'additional_details': 'additionalDetails'
        }

        self._event_grouping_id = None
        self._event_name = None
        self._compartment_id = None
        self._compartment_name = None
        self._resource_name = None
        self._resource_id = None
        self._availability_domain = None
        self._freeform_tags = None
        self._defined_tags = None
        self._identity = None
        self._request = None
        self._response = None
        self._state_change = None
        self._additional_details = None

    @property
    def event_grouping_id(self):
        """
        Gets the event_grouping_id of this Data.
        This value links multiple audit events that are part of the same API operation. For example,
        a long running API operations that emit an event at the start and the end of an operation
        would use the same value in this field for both events.


        :return: The event_grouping_id of this Data.
        :rtype: str
        """
        return self._event_grouping_id

    @event_grouping_id.setter
    def event_grouping_id(self, event_grouping_id):
        """
        Sets the event_grouping_id of this Data.
        This value links multiple audit events that are part of the same API operation. For example,
        a long running API operations that emit an event at the start and the end of an operation
        would use the same value in this field for both events.


        :param event_grouping_id: The event_grouping_id of this Data.
        :type: str
        """
        self._event_grouping_id = event_grouping_id

    @property
    def event_name(self):
        """
        Gets the event_name of this Data.
        Name of the API operation that generated this event.

        Example: `GetInstance`


        :return: The event_name of this Data.
        :rtype: str
        """
        return self._event_name

    @event_name.setter
    def event_name(self, event_name):
        """
        Sets the event_name of this Data.
        Name of the API operation that generated this event.

        Example: `GetInstance`


        :param event_name: The event_name of this Data.
        :type: str
        """
        self._event_name = event_name

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this Data.
        The `OCID`__ of the compartment of the resource
        emitting the event.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The compartment_id of this Data.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this Data.
        The `OCID`__ of the compartment of the resource
        emitting the event.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param compartment_id: The compartment_id of this Data.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def compartment_name(self):
        """
        Gets the compartment_name of this Data.
        The name of the compartment. This value is the friendly name associated with compartmentId.
        This value can change, but the service logs the value that appeared at the time of the audit
        event.

        Example: `CompartmentA`


        :return: The compartment_name of this Data.
        :rtype: str
        """
        return self._compartment_name

    @compartment_name.setter
    def compartment_name(self, compartment_name):
        """
        Sets the compartment_name of this Data.
        The name of the compartment. This value is the friendly name associated with compartmentId.
        This value can change, but the service logs the value that appeared at the time of the audit
        event.

        Example: `CompartmentA`


        :param compartment_name: The compartment_name of this Data.
        :type: str
        """
        self._compartment_name = compartment_name

    @property
    def resource_name(self):
        """
        Gets the resource_name of this Data.
        The name of the resource emitting the event.


        :return: The resource_name of this Data.
        :rtype: str
        """
        return self._resource_name

    @resource_name.setter
    def resource_name(self, resource_name):
        """
        Sets the resource_name of this Data.
        The name of the resource emitting the event.


        :param resource_name: The resource_name of this Data.
        :type: str
        """
        self._resource_name = resource_name

    @property
    def resource_id(self):
        """
        Gets the resource_id of this Data.
        An `OCID`__ or some other ID for the resource
        emitting the event.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :return: The resource_id of this Data.
        :rtype: str
        """
        return self._resource_id

    @resource_id.setter
    def resource_id(self, resource_id):
        """
        Sets the resource_id of this Data.
        An `OCID`__ or some other ID for the resource
        emitting the event.

        __ https://docs.cloud.oracle.com/Content/General/Concepts/identifiers.htm


        :param resource_id: The resource_id of this Data.
        :type: str
        """
        self._resource_id = resource_id

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this Data.
        The availability domain where the resource resides.


        :return: The availability_domain of this Data.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this Data.
        The availability domain where the resource resides.


        :param availability_domain: The availability_domain of this Data.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this Data.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name,
        type, or namespace. Exists for cross-compatibility only. For more information,
        see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this Data.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this Data.
        Free-form tags for this resource. Each tag is a simple key-value pair with no predefined name,
        type, or namespace. Exists for cross-compatibility only. For more information,
        see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this Data.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this Data.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more
        information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this Data.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this Data.
        Defined tags for this resource. Each key is predefined and scoped to a namespace. For more
        information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this Data.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def identity(self):
        """
        Gets the identity of this Data.

        :return: The identity of this Data.
        :rtype: oci.audit.models.Identity
        """
        return self._identity

    @identity.setter
    def identity(self, identity):
        """
        Sets the identity of this Data.

        :param identity: The identity of this Data.
        :type: oci.audit.models.Identity
        """
        self._identity = identity

    @property
    def request(self):
        """
        Gets the request of this Data.

        :return: The request of this Data.
        :rtype: oci.audit.models.Request
        """
        return self._request

    @request.setter
    def request(self, request):
        """
        Sets the request of this Data.

        :param request: The request of this Data.
        :type: oci.audit.models.Request
        """
        self._request = request

    @property
    def response(self):
        """
        Gets the response of this Data.

        :return: The response of this Data.
        :rtype: oci.audit.models.Response
        """
        return self._response

    @response.setter
    def response(self, response):
        """
        Sets the response of this Data.

        :param response: The response of this Data.
        :type: oci.audit.models.Response
        """
        self._response = response

    @property
    def state_change(self):
        """
        Gets the state_change of this Data.

        :return: The state_change of this Data.
        :rtype: oci.audit.models.StateChange
        """
        return self._state_change

    @state_change.setter
    def state_change(self, state_change):
        """
        Sets the state_change of this Data.

        :param state_change: The state_change of this Data.
        :type: oci.audit.models.StateChange
        """
        self._state_change = state_change

    @property
    def additional_details(self):
        """
        Gets the additional_details of this Data.
        A container object for attribues unique to the resource emitting the event.

        Example:

          -----
            {
              \"imageId\": \"ocid1.image.oc1.phx.<unique_ID>\",
              \"shape\": \"VM.Standard1.1\",
              \"type\": \"CustomerVmi\"
            }
          -----


        :return: The additional_details of this Data.
        :rtype: dict(str, object)
        """
        return self._additional_details

    @additional_details.setter
    def additional_details(self, additional_details):
        """
        Sets the additional_details of this Data.
        A container object for attribues unique to the resource emitting the event.

        Example:

          -----
            {
              \"imageId\": \"ocid1.image.oc1.phx.<unique_ID>\",
              \"shape\": \"VM.Standard1.1\",
              \"type\": \"CustomerVmi\"
            }
          -----


        :param additional_details: The additional_details of this Data.
        :type: dict(str, object)
        """
        self._additional_details = additional_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Recommendation(object):
    """
    A recommended protection rule for a web application. This recommendation can be accepted to apply it to the Web Application Firewall configuration for this policy.

    Use the `POST /waasPolicies/{waasPolicyId}/actions/acceptWafConfigRecommendations` method to accept recommended protection rules.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Recommendation object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Recommendation.
        :type key: str

        :param mod_security_rule_ids:
            The value to assign to the mod_security_rule_ids property of this Recommendation.
        :type mod_security_rule_ids: list[str]

        :param name:
            The value to assign to the name property of this Recommendation.
        :type name: str

        :param description:
            The value to assign to the description property of this Recommendation.
        :type description: str

        :param labels:
            The value to assign to the labels property of this Recommendation.
        :type labels: list[str]

        :param recommended_action:
            The value to assign to the recommended_action property of this Recommendation.
        :type recommended_action: str

        """
        self.swagger_types = {
            'key': 'str',
            'mod_security_rule_ids': 'list[str]',
            'name': 'str',
            'description': 'str',
            'labels': 'list[str]',
            'recommended_action': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'mod_security_rule_ids': 'modSecurityRuleIds',
            'name': 'name',
            'description': 'description',
            'labels': 'labels',
            'recommended_action': 'recommendedAction'
        }

        self._key = None
        self._mod_security_rule_ids = None
        self._name = None
        self._description = None
        self._labels = None
        self._recommended_action = None

    @property
    def key(self):
        """
        Gets the key of this Recommendation.
        The unique key for the recommended protection rule.


        :return: The key of this Recommendation.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Recommendation.
        The unique key for the recommended protection rule.


        :param key: The key of this Recommendation.
        :type: str
        """
        self._key = key

    @property
    def mod_security_rule_ids(self):
        """
        Gets the mod_security_rule_ids of this Recommendation.
        The list of the ModSecurity rule IDs associated with the protection rule.
        For more information about ModSecurity's open source WAF rules, see `Mod Security's documentation`__.

        __ https://www.modsecurity.org/CRS/Documentation/index.html


        :return: The mod_security_rule_ids of this Recommendation.
        :rtype: list[str]
        """
        return self._mod_security_rule_ids

    @mod_security_rule_ids.setter
    def mod_security_rule_ids(self, mod_security_rule_ids):
        """
        Sets the mod_security_rule_ids of this Recommendation.
        The list of the ModSecurity rule IDs associated with the protection rule.
        For more information about ModSecurity's open source WAF rules, see `Mod Security's documentation`__.

        __ https://www.modsecurity.org/CRS/Documentation/index.html


        :param mod_security_rule_ids: The mod_security_rule_ids of this Recommendation.
        :type: list[str]
        """
        self._mod_security_rule_ids = mod_security_rule_ids

    @property
    def name(self):
        """
        Gets the name of this Recommendation.
        The name of the recommended protection rule.


        :return: The name of this Recommendation.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this Recommendation.
        The name of the recommended protection rule.


        :param name: The name of this Recommendation.
        :type: str
        """
        self._name = name

    @property
    def description(self):
        """
        Gets the description of this Recommendation.
        The description of the recommended protection rule.


        :return: The description of this Recommendation.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this Recommendation.
        The description of the recommended protection rule.


        :param description: The description of this Recommendation.
        :type: str
        """
        self._description = description

    @property
    def labels(self):
        """
        Gets the labels of this Recommendation.
        The list of labels for the recommended protection rule.


        :return: The labels of this Recommendation.
        :rtype: list[str]
        """
        return self._labels

    @labels.setter
    def labels(self, labels):
        """
        Sets the labels of this Recommendation.
        The list of labels for the recommended protection rule.


        :param labels: The labels of this Recommendation.
        :type: list[str]
        """
        self._labels = labels

    @property
    def recommended_action(self):
        """
        Gets the recommended_action of this Recommendation.
        The recommended action to apply to the protection rule.


        :return: The recommended_action of this Recommendation.
        :rtype: str
        """
        return self._recommended_action

    @recommended_action.setter
    def recommended_action(self, recommended_action):
        """
        Sets the recommended_action of this Recommendation.
        The recommended action to apply to the protection rule.


        :param recommended_action: The recommended_action of this Recommendation.
        :type: str
        """
        self._recommended_action = recommended_action

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Filter(object):
    """
    The filter object for query usage.
    """

    #: A constant which can be used with the operator property of a Filter.
    #: This constant has a value of "AND"
    OPERATOR_AND = "AND"

    #: A constant which can be used with the operator property of a Filter.
    #: This constant has a value of "NOT"
    OPERATOR_NOT = "NOT"

    #: A constant which can be used with the operator property of a Filter.
    #: This constant has a value of "OR"
    OPERATOR_OR = "OR"

    def __init__(self, **kwargs):
        """
        Initializes a new Filter object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operator:
            The value to assign to the operator property of this Filter.
            Allowed values for this property are: "AND", "NOT", "OR", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type operator: str

        :param dimensions:
            The value to assign to the dimensions property of this Filter.
        :type dimensions: list[oci.usage_api.models.Dimension]

        :param tags:
            The value to assign to the tags property of this Filter.
        :type tags: list[oci.usage_api.models.Tag]

        :param filters:
            The value to assign to the filters property of this Filter.
        :type filters: list[oci.usage_api.models.Filter]

        """
        self.swagger_types = {
            'operator': 'str',
            'dimensions': 'list[Dimension]',
            'tags': 'list[Tag]',
            'filters': 'list[Filter]'
        }

        self.attribute_map = {
            'operator': 'operator',
            'dimensions': 'dimensions',
            'tags': 'tags',
            'filters': 'filters'
        }

        self._operator = None
        self._dimensions = None
        self._tags = None
        self._filters = None

    @property
    def operator(self):
        """
        Gets the operator of this Filter.
        The filter operator. Example: 'AND', 'OR', 'NOT'.

        Allowed values for this property are: "AND", "NOT", "OR", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The operator of this Filter.
        :rtype: str
        """
        return self._operator

    @operator.setter
    def operator(self, operator):
        """
        Sets the operator of this Filter.
        The filter operator. Example: 'AND', 'OR', 'NOT'.


        :param operator: The operator of this Filter.
        :type: str
        """
        allowed_values = ["AND", "NOT", "OR"]
        if not value_allowed_none_or_none_sentinel(operator, allowed_values):
            operator = 'UNKNOWN_ENUM_VALUE'
        self._operator = operator

    @property
    def dimensions(self):
        """
        Gets the dimensions of this Filter.
        The dimensions to filter on.


        :return: The dimensions of this Filter.
        :rtype: list[oci.usage_api.models.Dimension]
        """
        return self._dimensions

    @dimensions.setter
    def dimensions(self, dimensions):
        """
        Sets the dimensions of this Filter.
        The dimensions to filter on.


        :param dimensions: The dimensions of this Filter.
        :type: list[oci.usage_api.models.Dimension]
        """
        self._dimensions = dimensions

    @property
    def tags(self):
        """
        Gets the tags of this Filter.
        The tags to filter on.


        :return: The tags of this Filter.
        :rtype: list[oci.usage_api.models.Tag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Filter.
        The tags to filter on.


        :param tags: The tags of this Filter.
        :type: list[oci.usage_api.models.Tag]
        """
        self._tags = tags

    @property
    def filters(self):
        """
        Gets the filters of this Filter.
        The nested filter object.


        :return: The filters of this Filter.
        :rtype: list[oci.usage_api.models.Filter]
        """
        return self._filters

    @filters.setter
    def filters(self, filters):
        """
        Sets the filters of this Filter.
        The nested filter object.


        :param filters: The filters of this Filter.
        :type: list[oci.usage_api.models.Filter]
        """
        self._filters = filters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AlarmHistoryEntry(object):
    """
    An alarm history entry indicating a description of the entry and the time that the entry occurred.
    If the entry corresponds to a state transition, such as OK to Firing, then the entry also includes a transition timestamp.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new AlarmHistoryEntry object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param summary:
            The value to assign to the summary property of this AlarmHistoryEntry.
        :type summary: str

        :param timestamp:
            The value to assign to the timestamp property of this AlarmHistoryEntry.
        :type timestamp: datetime

        :param timestamp_triggered:
            The value to assign to the timestamp_triggered property of this AlarmHistoryEntry.
        :type timestamp_triggered: datetime

        """
        self.swagger_types = {
            'summary': 'str',
            'timestamp': 'datetime',
            'timestamp_triggered': 'datetime'
        }

        self.attribute_map = {
            'summary': 'summary',
            'timestamp': 'timestamp',
            'timestamp_triggered': 'timestampTriggered'
        }

        self._summary = None
        self._timestamp = None
        self._timestamp_triggered = None

    @property
    def summary(self):
        """
        **[Required]** Gets the summary of this AlarmHistoryEntry.
        Description for this alarm history entry.

        Example 1 - alarm state history entry: `The alarm state is FIRING`

        Example 2 - alarm state transition history entry: `State transitioned from OK to Firing`


        :return: The summary of this AlarmHistoryEntry.
        :rtype: str
        """
        return self._summary

    @summary.setter
    def summary(self, summary):
        """
        Sets the summary of this AlarmHistoryEntry.
        Description for this alarm history entry.

        Example 1 - alarm state history entry: `The alarm state is FIRING`

        Example 2 - alarm state transition history entry: `State transitioned from OK to Firing`


        :param summary: The summary of this AlarmHistoryEntry.
        :type: str
        """
        self._summary = summary

    @property
    def timestamp(self):
        """
        **[Required]** Gets the timestamp of this AlarmHistoryEntry.
        Timestamp for this alarm history entry. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :return: The timestamp of this AlarmHistoryEntry.
        :rtype: datetime
        """
        return self._timestamp

    @timestamp.setter
    def timestamp(self, timestamp):
        """
        Sets the timestamp of this AlarmHistoryEntry.
        Timestamp for this alarm history entry. Format defined by RFC3339.

        Example: `2019-02-01T01:02:29.600Z`


        :param timestamp: The timestamp of this AlarmHistoryEntry.
        :type: datetime
        """
        self._timestamp = timestamp

    @property
    def timestamp_triggered(self):
        """
        Gets the timestamp_triggered of this AlarmHistoryEntry.
        Timestamp for the transition of the alarm state. For example, the time when the alarm transitioned from OK to Firing.
        Available for state transition entries only. Note: A three-minute lag for this value accounts for any late-arriving metrics.

        Example: `2019-02-01T0:59:00.789Z`


        :return: The timestamp_triggered of this AlarmHistoryEntry.
        :rtype: datetime
        """
        return self._timestamp_triggered

    @timestamp_triggered.setter
    def timestamp_triggered(self, timestamp_triggered):
        """
        Sets the timestamp_triggered of this AlarmHistoryEntry.
        Timestamp for the transition of the alarm state. For example, the time when the alarm transitioned from OK to Firing.
        Available for state transition entries only. Note: A three-minute lag for this value accounts for any late-arriving metrics.

        Example: `2019-02-01T0:59:00.789Z`


        :param timestamp_triggered: The timestamp_triggered of this AlarmHistoryEntry.
        :type: datetime
        """
        self._timestamp_triggered = timestamp_triggered

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class QueryParameterValidationRequestPolicy(object):
    """
    Validate the URL query parameters on the incoming API requests on a specific route.
    """

    #: A constant which can be used with the validation_mode property of a QueryParameterValidationRequestPolicy.
    #: This constant has a value of "ENFORCING"
    VALIDATION_MODE_ENFORCING = "ENFORCING"

    #: A constant which can be used with the validation_mode property of a QueryParameterValidationRequestPolicy.
    #: This constant has a value of "PERMISSIVE"
    VALIDATION_MODE_PERMISSIVE = "PERMISSIVE"

    #: A constant which can be used with the validation_mode property of a QueryParameterValidationRequestPolicy.
    #: This constant has a value of "DISABLED"
    VALIDATION_MODE_DISABLED = "DISABLED"

    def __init__(self, **kwargs):
        """
        Initializes a new QueryParameterValidationRequestPolicy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parameters:
            The value to assign to the parameters property of this QueryParameterValidationRequestPolicy.
        :type parameters: list[oci.apigateway.models.QueryParameterValidationItem]

        :param validation_mode:
            The value to assign to the validation_mode property of this QueryParameterValidationRequestPolicy.
            Allowed values for this property are: "ENFORCING", "PERMISSIVE", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type validation_mode: str

        """
        self.swagger_types = {
            'parameters': 'list[QueryParameterValidationItem]',
            'validation_mode': 'str'
        }

        self.attribute_map = {
            'parameters': 'parameters',
            'validation_mode': 'validationMode'
        }

        self._parameters = None
        self._validation_mode = None

    @property
    def parameters(self):
        """
        Gets the parameters of this QueryParameterValidationRequestPolicy.

        :return: The parameters of this QueryParameterValidationRequestPolicy.
        :rtype: list[oci.apigateway.models.QueryParameterValidationItem]
        """
        return self._parameters

    @parameters.setter
    def parameters(self, parameters):
        """
        Sets the parameters of this QueryParameterValidationRequestPolicy.

        :param parameters: The parameters of this QueryParameterValidationRequestPolicy.
        :type: list[oci.apigateway.models.QueryParameterValidationItem]
        """
        self._parameters = parameters

    @property
    def validation_mode(self):
        """
        Gets the validation_mode of this QueryParameterValidationRequestPolicy.
        Validation behavior mode.

        In `ENFORCING` mode, upon a validation failure, the request will be rejected with a 4xx response
        and not sent to the backend.

        In `PERMISSIVE` mode, the result of the validation will be exposed as metrics while the request
        will follow the normal path.

        `DISABLED` type turns the validation off.

        Allowed values for this property are: "ENFORCING", "PERMISSIVE", "DISABLED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The validation_mode of this QueryParameterValidationRequestPolicy.
        :rtype: str
        """
        return self._validation_mode

    @validation_mode.setter
    def validation_mode(self, validation_mode):
        """
        Sets the validation_mode of this QueryParameterValidationRequestPolicy.
        Validation behavior mode.

        In `ENFORCING` mode, upon a validation failure, the request will be rejected with a 4xx response
        and not sent to the backend.

        In `PERMISSIVE` mode, the result of the validation will be exposed as metrics while the request
        will follow the normal path.

        `DISABLED` type turns the validation off.


        :param validation_mode: The validation_mode of this QueryParameterValidationRequestPolicy.
        :type: str
        """
        allowed_values = ["ENFORCING", "PERMISSIVE", "DISABLED"]
        if not value_allowed_none_or_none_sentinel(validation_mode, allowed_values):
            validation_mode = 'UNKNOWN_ENUM_VALUE'
        self._validation_mode = validation_mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class LogAnalyticsParserFunction(object):
    """
    LogAnalyticsParserFunction
    """

    def __init__(self, **kwargs):
        """
        Initializes a new LogAnalyticsParserFunction object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param parser_meta_plugin:
            The value to assign to the parser_meta_plugin property of this LogAnalyticsParserFunction.
        :type parser_meta_plugin: oci.log_analytics.models.LogAnalyticsParserMetaPlugin

        :param parser_function_id:
            The value to assign to the parser_function_id property of this LogAnalyticsParserFunction.
        :type parser_function_id: int

        :param parser_function_name:
            The value to assign to the parser_function_name property of this LogAnalyticsParserFunction.
        :type parser_function_name: str

        :param is_enabled:
            The value to assign to the is_enabled property of this LogAnalyticsParserFunction.
        :type is_enabled: bool

        :param is_system:
            The value to assign to the is_system property of this LogAnalyticsParserFunction.
        :type is_system: bool

        :param parser_id:
            The value to assign to the parser_id property of this LogAnalyticsParserFunction.
        :type parser_id: int

        :param parser_name:
            The value to assign to the parser_name property of this LogAnalyticsParserFunction.
        :type parser_name: str

        :param parser_meta_plugin_name:
            The value to assign to the parser_meta_plugin_name property of this LogAnalyticsParserFunction.
        :type parser_meta_plugin_name: str

        :param parser_function_priority:
            The value to assign to the parser_function_priority property of this LogAnalyticsParserFunction.
        :type parser_function_priority: int

        :param parser_function_parameters:
            The value to assign to the parser_function_parameters property of this LogAnalyticsParserFunction.
        :type parser_function_parameters: list[oci.log_analytics.models.LogAnalyticsParserFunctionParameter]

        """
        self.swagger_types = {
            'parser_meta_plugin': 'LogAnalyticsParserMetaPlugin',
            'parser_function_id': 'int',
            'parser_function_name': 'str',
            'is_enabled': 'bool',
            'is_system': 'bool',
            'parser_id': 'int',
            'parser_name': 'str',
            'parser_meta_plugin_name': 'str',
            'parser_function_priority': 'int',
            'parser_function_parameters': 'list[LogAnalyticsParserFunctionParameter]'
        }

        self.attribute_map = {
            'parser_meta_plugin': 'parserMetaPlugin',
            'parser_function_id': 'parserFunctionId',
            'parser_function_name': 'parserFunctionName',
            'is_enabled': 'isEnabled',
            'is_system': 'isSystem',
            'parser_id': 'parserId',
            'parser_name': 'parserName',
            'parser_meta_plugin_name': 'parserMetaPluginName',
            'parser_function_priority': 'parserFunctionPriority',
            'parser_function_parameters': 'parserFunctionParameters'
        }

        self._parser_meta_plugin = None
        self._parser_function_id = None
        self._parser_function_name = None
        self._is_enabled = None
        self._is_system = None
        self._parser_id = None
        self._parser_name = None
        self._parser_meta_plugin_name = None
        self._parser_function_priority = None
        self._parser_function_parameters = None

    @property
    def parser_meta_plugin(self):
        """
        Gets the parser_meta_plugin of this LogAnalyticsParserFunction.

        :return: The parser_meta_plugin of this LogAnalyticsParserFunction.
        :rtype: oci.log_analytics.models.LogAnalyticsParserMetaPlugin
        """
        return self._parser_meta_plugin

    @parser_meta_plugin.setter
    def parser_meta_plugin(self, parser_meta_plugin):
        """
        Sets the parser_meta_plugin of this LogAnalyticsParserFunction.

        :param parser_meta_plugin: The parser_meta_plugin of this LogAnalyticsParserFunction.
        :type: oci.log_analytics.models.LogAnalyticsParserMetaPlugin
        """
        self._parser_meta_plugin = parser_meta_plugin

    @property
    def parser_function_id(self):
        """
        Gets the parser_function_id of this LogAnalyticsParserFunction.
        The parser function unique identifier.


        :return: The parser_function_id of this LogAnalyticsParserFunction.
        :rtype: int
        """
        return self._parser_function_id

    @parser_function_id.setter
    def parser_function_id(self, parser_function_id):
        """
        Sets the parser_function_id of this LogAnalyticsParserFunction.
        The parser function unique identifier.


        :param parser_function_id: The parser_function_id of this LogAnalyticsParserFunction.
        :type: int
        """
        self._parser_function_id = parser_function_id

    @property
    def parser_function_name(self):
        """
        Gets the parser_function_name of this LogAnalyticsParserFunction.
        The parser function internal name.


        :return: The parser_function_name of this LogAnalyticsParserFunction.
        :rtype: str
        """
        return self._parser_function_name

    @parser_function_name.setter
    def parser_function_name(self, parser_function_name):
        """
        Sets the parser_function_name of this LogAnalyticsParserFunction.
        The parser function internal name.


        :param parser_function_name: The parser_function_name of this LogAnalyticsParserFunction.
        :type: str
        """
        self._parser_function_name = parser_function_name

    @property
    def is_enabled(self):
        """
        Gets the is_enabled of this LogAnalyticsParserFunction.
        A flag inidcating whether or not the parser function is enabled.


        :return: The is_enabled of this LogAnalyticsParserFunction.
        :rtype: bool
        """
        return self._is_enabled

    @is_enabled.setter
    def is_enabled(self, is_enabled):
        """
        Sets the is_enabled of this LogAnalyticsParserFunction.
        A flag inidcating whether or not the parser function is enabled.


        :param is_enabled: The is_enabled of this LogAnalyticsParserFunction.
        :type: bool
        """
        self._is_enabled = is_enabled

    @property
    def is_system(self):
        """
        Gets the is_system of this LogAnalyticsParserFunction.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :return: The is_system of this LogAnalyticsParserFunction.
        :rtype: bool
        """
        return self._is_system

    @is_system.setter
    def is_system(self, is_system):
        """
        Sets the is_system of this LogAnalyticsParserFunction.
        The system flag.  A value of false denotes a custom, or user
        defined object.  A value of true denotes a built in object.


        :param is_system: The is_system of this LogAnalyticsParserFunction.
        :type: bool
        """
        self._is_system = is_system

    @property
    def parser_id(self):
        """
        Gets the parser_id of this LogAnalyticsParserFunction.
        The associated parser unique identifier.


        :return: The parser_id of this LogAnalyticsParserFunction.
        :rtype: int
        """
        return self._parser_id

    @parser_id.setter
    def parser_id(self, parser_id):
        """
        Sets the parser_id of this LogAnalyticsParserFunction.
        The associated parser unique identifier.


        :param parser_id: The parser_id of this LogAnalyticsParserFunction.
        :type: int
        """
        self._parser_id = parser_id

    @property
    def parser_name(self):
        """
        Gets the parser_name of this LogAnalyticsParserFunction.
        The associated parser internal name.


        :return: The parser_name of this LogAnalyticsParserFunction.
        :rtype: str
        """
        return self._parser_name

    @parser_name.setter
    def parser_name(self, parser_name):
        """
        Sets the parser_name of this LogAnalyticsParserFunction.
        The associated parser internal name.


        :param parser_name: The parser_name of this LogAnalyticsParserFunction.
        :type: str
        """
        self._parser_name = parser_name

    @property
    def parser_meta_plugin_name(self):
        """
        Gets the parser_meta_plugin_name of this LogAnalyticsParserFunction.
        The plugin internal name.


        :return: The parser_meta_plugin_name of this LogAnalyticsParserFunction.
        :rtype: str
        """
        return self._parser_meta_plugin_name

    @parser_meta_plugin_name.setter
    def parser_meta_plugin_name(self, parser_meta_plugin_name):
        """
        Sets the parser_meta_plugin_name of this LogAnalyticsParserFunction.
        The plugin internal name.


        :param parser_meta_plugin_name: The parser_meta_plugin_name of this LogAnalyticsParserFunction.
        :type: str
        """
        self._parser_meta_plugin_name = parser_meta_plugin_name

    @property
    def parser_function_priority(self):
        """
        Gets the parser_function_priority of this LogAnalyticsParserFunction.
        The parser function priority.


        :return: The parser_function_priority of this LogAnalyticsParserFunction.
        :rtype: int
        """
        return self._parser_function_priority

    @parser_function_priority.setter
    def parser_function_priority(self, parser_function_priority):
        """
        Sets the parser_function_priority of this LogAnalyticsParserFunction.
        The parser function priority.


        :param parser_function_priority: The parser_function_priority of this LogAnalyticsParserFunction.
        :type: int
        """
        self._parser_function_priority = parser_function_priority

    @property
    def parser_function_parameters(self):
        """
        Gets the parser_function_parameters of this LogAnalyticsParserFunction.
        The parser function parameter list.


        :return: The parser_function_parameters of this LogAnalyticsParserFunction.
        :rtype: list[oci.log_analytics.models.LogAnalyticsParserFunctionParameter]
        """
        return self._parser_function_parameters

    @parser_function_parameters.setter
    def parser_function_parameters(self, parser_function_parameters):
        """
        Sets the parser_function_parameters of this LogAnalyticsParserFunction.
        The parser function parameter list.


        :param parser_function_parameters: The parser_function_parameters of this LogAnalyticsParserFunction.
        :type: list[oci.log_analytics.models.LogAnalyticsParserFunctionParameter]
        """
        self._parser_function_parameters = parser_function_parameters

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ShapeNumaNodesPerSocketPlatformOptions(object):
    """
    Configuration options for NUMA nodes per socket.
    """

    #: A constant which can be used with the service_allowed_values property of a ShapeNumaNodesPerSocketPlatformOptions.
    #: This constant has a value of "NPS0"
    SERVICE_ALLOWED_VALUES_NPS0 = "NPS0"

    #: A constant which can be used with the service_allowed_values property of a ShapeNumaNodesPerSocketPlatformOptions.
    #: This constant has a value of "NPS1"
    SERVICE_ALLOWED_VALUES_NPS1 = "NPS1"

    #: A constant which can be used with the service_allowed_values property of a ShapeNumaNodesPerSocketPlatformOptions.
    #: This constant has a value of "NPS2"
    SERVICE_ALLOWED_VALUES_NPS2 = "NPS2"

    #: A constant which can be used with the service_allowed_values property of a ShapeNumaNodesPerSocketPlatformOptions.
    #: This constant has a value of "NPS4"
    SERVICE_ALLOWED_VALUES_NPS4 = "NPS4"

    def __init__(self, **kwargs):
        """
        Initializes a new ShapeNumaNodesPerSocketPlatformOptions object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param service_allowed_values:
            The value to assign to the service_allowed_values property of this ShapeNumaNodesPerSocketPlatformOptions.
            Allowed values for items in this list are: "NPS0", "NPS1", "NPS2", "NPS4", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type service_allowed_values: list[str]

        :param default_value:
            The value to assign to the default_value property of this ShapeNumaNodesPerSocketPlatformOptions.
        :type default_value: str

        """
        self.swagger_types = {
            'service_allowed_values': 'list[str]',
            'default_value': 'str'
        }

        self.attribute_map = {
            'service_allowed_values': 'allowedValues',
            'default_value': 'defaultValue'
        }

        self._service_allowed_values = None
        self._default_value = None

    @property
    def service_allowed_values(self):
        """
        Gets the service_allowed_values of this ShapeNumaNodesPerSocketPlatformOptions.
        The supported values for this platform configuration property.

        Allowed values for items in this list are: "NPS0", "NPS1", "NPS2", "NPS4", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The service_allowed_values of this ShapeNumaNodesPerSocketPlatformOptions.
        :rtype: list[str]
        """
        return self._service_allowed_values

    @service_allowed_values.setter
    def service_allowed_values(self, service_allowed_values):
        """
        Sets the service_allowed_values of this ShapeNumaNodesPerSocketPlatformOptions.
        The supported values for this platform configuration property.


        :param service_allowed_values: The service_allowed_values of this ShapeNumaNodesPerSocketPlatformOptions.
        :type: list[str]
        """
        allowed_values = ["NPS0", "NPS1", "NPS2", "NPS4"]
        if service_allowed_values:
            service_allowed_values[:] = ['UNKNOWN_ENUM_VALUE' if not value_allowed_none_or_none_sentinel(x, allowed_values) else x for x in service_allowed_values]
        self._service_allowed_values = service_allowed_values

    @property
    def default_value(self):
        """
        Gets the default_value of this ShapeNumaNodesPerSocketPlatformOptions.
        The default NUMA nodes per socket configuration.


        :return: The default_value of this ShapeNumaNodesPerSocketPlatformOptions.
        :rtype: str
        """
        return self._default_value

    @default_value.setter
    def default_value(self, default_value):
        """
        Sets the default_value of this ShapeNumaNodesPerSocketPlatformOptions.
        The default NUMA nodes per socket configuration.


        :param default_value: The default_value of this ShapeNumaNodesPerSocketPlatformOptions.
        :type: str
        """
        self._default_value = default_value

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateSSLCipherSuiteDetails(object):
    """
    The configuration details for updating an SSL cipher suite.

    **Warning:** Oracle recommends that you avoid using any confidential information when you supply string values using the API.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateSSLCipherSuiteDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param ciphers:
            The value to assign to the ciphers property of this UpdateSSLCipherSuiteDetails.
        :type ciphers: list[str]

        """
        self.swagger_types = {
            'ciphers': 'list[str]'
        }

        self.attribute_map = {
            'ciphers': 'ciphers'
        }

        self._ciphers = None

    @property
    def ciphers(self):
        """
        **[Required]** Gets the ciphers of this UpdateSSLCipherSuiteDetails.
        A list of SSL ciphers the load balancer must support for HTTPS or SSL connections.

        The following ciphers are valid values for this property:

        *  __TLSv1.2 ciphers__

                \"AES128-GCM-SHA256\"
                \"AES128-SHA256\"
                \"AES256-GCM-SHA384\"
                \"AES256-SHA256\"
                \"DH-DSS-AES128-GCM-SHA256\"
                \"DH-DSS-AES128-SHA256\"
                \"DH-DSS-AES256-GCM-SHA384\"
                \"DH-DSS-AES256-SHA256\"
                \"DH-RSA-AES128-GCM-SHA256\"
                \"DH-RSA-AES128-SHA256\"
                \"DH-RSA-AES256-GCM-SHA384\"
                \"DH-RSA-AES256-SHA256\"
                \"DHE-DSS-AES128-GCM-SHA256\"
                \"DHE-DSS-AES128-SHA256\"
                \"DHE-DSS-AES256-GCM-SHA384\"
                \"DHE-DSS-AES256-SHA256\"
                \"DHE-RSA-AES128-GCM-SHA256\"
                \"DHE-RSA-AES128-SHA256\"
                \"DHE-RSA-AES256-GCM-SHA384\"
                \"DHE-RSA-AES256-SHA256\"
                \"ECDH-ECDSA-AES128-GCM-SHA256\"
                \"ECDH-ECDSA-AES128-SHA256\"
                \"ECDH-ECDSA-AES256-GCM-SHA384\"
                \"ECDH-ECDSA-AES256-SHA384\"
                \"ECDH-RSA-AES128-GCM-SHA256\"
                \"ECDH-RSA-AES128-SHA256\"
                \"ECDH-RSA-AES256-GCM-SHA384\"
                \"ECDH-RSA-AES256-SHA384\"
                \"ECDHE-ECDSA-AES128-GCM-SHA256\"
                \"ECDHE-ECDSA-AES128-SHA256\"
                \"ECDHE-ECDSA-AES256-GCM-SHA384\"
                \"ECDHE-ECDSA-AES256-SHA384\"
                \"ECDHE-RSA-AES128-GCM-SHA256\"
                \"ECDHE-RSA-AES128-SHA256\"
                \"ECDHE-RSA-AES256-GCM-SHA384\"
                \"ECDHE-RSA-AES256-SHA384\"

        *  __TLSv1 ciphers also supported by TLSv1.2__

                \"AES128-SHA\"
                \"AES256-SHA\"
                \"CAMELLIA128-SHA\"
                \"CAMELLIA256-SHA\"
                \"DES-CBC3-SHA\"
                \"DH-DSS-AES128-SHA\"
                \"DH-DSS-AES256-SHA\"
                \"DH-DSS-CAMELLIA128-SHA\"
                \"DH-DSS-CAMELLIA256-SHA\"
                \"DH-DSS-DES-CBC3-SHAv\"
                \"DH-DSS-SEED-SHA\"
                \"DH-RSA-AES128-SHA\"
                \"DH-RSA-AES256-SHA\"
                \"DH-RSA-CAMELLIA128-SHA\"
                \"DH-RSA-CAMELLIA256-SHA\"
                \"DH-RSA-DES-CBC3-SHA\"
                \"DH-RSA-SEED-SHA\"
                \"DHE-DSS-AES128-SHA\"
                \"DHE-DSS-AES256-SHA\"
                \"DHE-DSS-CAMELLIA128-SHA\"
                \"DHE-DSS-CAMELLIA256-SHA\"
                \"DHE-DSS-DES-CBC3-SHA\"
                \"DHE-DSS-SEED-SHA\"
                \"DHE-RSA-AES128-SHA\"
                \"DHE-RSA-AES256-SHA\"
                \"DHE-RSA-CAMELLIA128-SHA\"
                \"DHE-RSA-CAMELLIA256-SHA\"
                \"DHE-RSA-DES-CBC3-SHA\"
                \"DHE-RSA-SEED-SHA\"
                \"ECDH-ECDSA-AES128-SHA\"
                \"ECDH-ECDSA-AES256-SHA\"
                \"ECDH-ECDSA-DES-CBC3-SHA\"
                \"ECDH-ECDSA-RC4-SHA\"
                \"ECDH-RSA-AES128-SHA\"
                \"ECDH-RSA-AES256-SHA\"
                \"ECDH-RSA-DES-CBC3-SHA\"
                \"ECDH-RSA-RC4-SHA\"
                \"ECDHE-ECDSA-AES128-SHA\"
                \"ECDHE-ECDSA-AES256-SHA\"
                \"ECDHE-ECDSA-DES-CBC3-SHA\"
                \"ECDHE-ECDSA-RC4-SHA\"
                \"ECDHE-RSA-AES128-SHA\"
                \"ECDHE-RSA-AES256-SHA\"
                \"ECDHE-RSA-DES-CBC3-SHA\"
                \"ECDHE-RSA-RC4-SHA\"
                \"IDEA-CBC-SHA\"
                \"KRB5-DES-CBC3-MD5\"
                \"KRB5-DES-CBC3-SHA\"
                \"KRB5-IDEA-CBC-MD5\"
                \"KRB5-IDEA-CBC-SHA\"
                \"KRB5-RC4-MD5\"
                \"KRB5-RC4-SHA\"
                \"PSK-3DES-EDE-CBC-SHA\"
                \"PSK-AES128-CBC-SHA\"
                \"PSK-AES256-CBC-SHA\"
                \"PSK-RC4-SHA\"
                \"RC4-MD5\"
                \"RC4-SHA\"
                \"SEED-SHA\"

        example: `[\"ECDHE-RSA-AES256-GCM-SHA384\",\"ECDHE-ECDSA-AES256-GCM-SHA384\",\"ECDHE-RSA-AES128-GCM-SHA256\"]`


        :return: The ciphers of this UpdateSSLCipherSuiteDetails.
        :rtype: list[str]
        """
        return self._ciphers

    @ciphers.setter
    def ciphers(self, ciphers):
        """
        Sets the ciphers of this UpdateSSLCipherSuiteDetails.
        A list of SSL ciphers the load balancer must support for HTTPS or SSL connections.

        The following ciphers are valid values for this property:

        *  __TLSv1.2 ciphers__

                \"AES128-GCM-SHA256\"
                \"AES128-SHA256\"
                \"AES256-GCM-SHA384\"
                \"AES256-SHA256\"
                \"DH-DSS-AES128-GCM-SHA256\"
                \"DH-DSS-AES128-SHA256\"
                \"DH-DSS-AES256-GCM-SHA384\"
                \"DH-DSS-AES256-SHA256\"
                \"DH-RSA-AES128-GCM-SHA256\"
                \"DH-RSA-AES128-SHA256\"
                \"DH-RSA-AES256-GCM-SHA384\"
                \"DH-RSA-AES256-SHA256\"
                \"DHE-DSS-AES128-GCM-SHA256\"
                \"DHE-DSS-AES128-SHA256\"
                \"DHE-DSS-AES256-GCM-SHA384\"
                \"DHE-DSS-AES256-SHA256\"
                \"DHE-RSA-AES128-GCM-SHA256\"
                \"DHE-RSA-AES128-SHA256\"
                \"DHE-RSA-AES256-GCM-SHA384\"
                \"DHE-RSA-AES256-SHA256\"
                \"ECDH-ECDSA-AES128-GCM-SHA256\"
                \"ECDH-ECDSA-AES128-SHA256\"
                \"ECDH-ECDSA-AES256-GCM-SHA384\"
                \"ECDH-ECDSA-AES256-SHA384\"
                \"ECDH-RSA-AES128-GCM-SHA256\"
                \"ECDH-RSA-AES128-SHA256\"
                \"ECDH-RSA-AES256-GCM-SHA384\"
                \"ECDH-RSA-AES256-SHA384\"
                \"ECDHE-ECDSA-AES128-GCM-SHA256\"
                \"ECDHE-ECDSA-AES128-SHA256\"
                \"ECDHE-ECDSA-AES256-GCM-SHA384\"
                \"ECDHE-ECDSA-AES256-SHA384\"
                \"ECDHE-RSA-AES128-GCM-SHA256\"
                \"ECDHE-RSA-AES128-SHA256\"
                \"ECDHE-RSA-AES256-GCM-SHA384\"
                \"ECDHE-RSA-AES256-SHA384\"

        *  __TLSv1 ciphers also supported by TLSv1.2__

                \"AES128-SHA\"
                \"AES256-SHA\"
                \"CAMELLIA128-SHA\"
                \"CAMELLIA256-SHA\"
                \"DES-CBC3-SHA\"
                \"DH-DSS-AES128-SHA\"
                \"DH-DSS-AES256-SHA\"
                \"DH-DSS-CAMELLIA128-SHA\"
                \"DH-DSS-CAMELLIA256-SHA\"
                \"DH-DSS-DES-CBC3-SHAv\"
                \"DH-DSS-SEED-SHA\"
                \"DH-RSA-AES128-SHA\"
                \"DH-RSA-AES256-SHA\"
                \"DH-RSA-CAMELLIA128-SHA\"
                \"DH-RSA-CAMELLIA256-SHA\"
                \"DH-RSA-DES-CBC3-SHA\"
                \"DH-RSA-SEED-SHA\"
                \"DHE-DSS-AES128-SHA\"
                \"DHE-DSS-AES256-SHA\"
                \"DHE-DSS-CAMELLIA128-SHA\"
                \"DHE-DSS-CAMELLIA256-SHA\"
                \"DHE-DSS-DES-CBC3-SHA\"
                \"DHE-DSS-SEED-SHA\"
                \"DHE-RSA-AES128-SHA\"
                \"DHE-RSA-AES256-SHA\"
                \"DHE-RSA-CAMELLIA128-SHA\"
                \"DHE-RSA-CAMELLIA256-SHA\"
                \"DHE-RSA-DES-CBC3-SHA\"
                \"DHE-RSA-SEED-SHA\"
                \"ECDH-ECDSA-AES128-SHA\"
                \"ECDH-ECDSA-AES256-SHA\"
                \"ECDH-ECDSA-DES-CBC3-SHA\"
                \"ECDH-ECDSA-RC4-SHA\"
                \"ECDH-RSA-AES128-SHA\"
                \"ECDH-RSA-AES256-SHA\"
                \"ECDH-RSA-DES-CBC3-SHA\"
                \"ECDH-RSA-RC4-SHA\"
                \"ECDHE-ECDSA-AES128-SHA\"
                \"ECDHE-ECDSA-AES256-SHA\"
                \"ECDHE-ECDSA-DES-CBC3-SHA\"
                \"ECDHE-ECDSA-RC4-SHA\"
                \"ECDHE-RSA-AES128-SHA\"
                \"ECDHE-RSA-AES256-SHA\"
                \"ECDHE-RSA-DES-CBC3-SHA\"
                \"ECDHE-RSA-RC4-SHA\"
                \"IDEA-CBC-SHA\"
                \"KRB5-DES-CBC3-MD5\"
                \"KRB5-DES-CBC3-SHA\"
                \"KRB5-IDEA-CBC-MD5\"
                \"KRB5-IDEA-CBC-SHA\"
                \"KRB5-RC4-MD5\"
                \"KRB5-RC4-SHA\"
                \"PSK-3DES-EDE-CBC-SHA\"
                \"PSK-AES128-CBC-SHA\"
                \"PSK-AES256-CBC-SHA\"
                \"PSK-RC4-SHA\"
                \"RC4-MD5\"
                \"RC4-SHA\"
                \"SEED-SHA\"

        example: `[\"ECDHE-RSA-AES256-GCM-SHA384\",\"ECDHE-ECDSA-AES256-GCM-SHA384\",\"ECDHE-RSA-AES128-GCM-SHA256\"]`


        :param ciphers: The ciphers of this UpdateSSLCipherSuiteDetails.
        :type: list[str]
        """
        self._ciphers = ciphers

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Strategy(object):
    """
    The metadata associated with the strategy. The strategy is the method used to apply the recommendation.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Strategy object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param strategy_name:
            The value to assign to the strategy_name property of this Strategy.
        :type strategy_name: str

        :param is_default:
            The value to assign to the is_default property of this Strategy.
        :type is_default: bool

        :param parameters_definition:
            The value to assign to the parameters_definition property of this Strategy.
        :type parameters_definition: list[oci.optimizer.models.StrategyParameter]

        """
        self.swagger_types = {
            'strategy_name': 'str',
            'is_default': 'bool',
            'parameters_definition': 'list[StrategyParameter]'
        }

        self.attribute_map = {
            'strategy_name': 'strategyName',
            'is_default': 'isDefault',
            'parameters_definition': 'parametersDefinition'
        }

        self._strategy_name = None
        self._is_default = None
        self._parameters_definition = None

    @property
    def strategy_name(self):
        """
        **[Required]** Gets the strategy_name of this Strategy.
        The name of the strategy.


        :return: The strategy_name of this Strategy.
        :rtype: str
        """
        return self._strategy_name

    @strategy_name.setter
    def strategy_name(self, strategy_name):
        """
        Sets the strategy_name of this Strategy.
        The name of the strategy.


        :param strategy_name: The strategy_name of this Strategy.
        :type: str
        """
        self._strategy_name = strategy_name

    @property
    def is_default(self):
        """
        **[Required]** Gets the is_default of this Strategy.
        Whether this is the default recommendation strategy.


        :return: The is_default of this Strategy.
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """
        Sets the is_default of this Strategy.
        Whether this is the default recommendation strategy.


        :param is_default: The is_default of this Strategy.
        :type: bool
        """
        self._is_default = is_default

    @property
    def parameters_definition(self):
        """
        Gets the parameters_definition of this Strategy.
        The list of strategies for the parameters.


        :return: The parameters_definition of this Strategy.
        :rtype: list[oci.optimizer.models.StrategyParameter]
        """
        return self._parameters_definition

    @parameters_definition.setter
    def parameters_definition(self, parameters_definition):
        """
        Sets the parameters_definition of this Strategy.
        The list of strategies for the parameters.


        :param parameters_definition: The parameters_definition of this Strategy.
        :type: list[oci.optimizer.models.StrategyParameter]
        """
        self._parameters_definition = parameters_definition

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateInstanceAgentConfigDetails(object):
    """
    Configuration options for the Oracle Cloud Agent software running on the instance.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateInstanceAgentConfigDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param is_monitoring_disabled:
            The value to assign to the is_monitoring_disabled property of this UpdateInstanceAgentConfigDetails.
        :type is_monitoring_disabled: bool

        :param is_management_disabled:
            The value to assign to the is_management_disabled property of this UpdateInstanceAgentConfigDetails.
        :type is_management_disabled: bool

        :param are_all_plugins_disabled:
            The value to assign to the are_all_plugins_disabled property of this UpdateInstanceAgentConfigDetails.
        :type are_all_plugins_disabled: bool

        :param plugins_config:
            The value to assign to the plugins_config property of this UpdateInstanceAgentConfigDetails.
        :type plugins_config: list[oci.core.models.InstanceAgentPluginConfigDetails]

        """
        self.swagger_types = {
            'is_monitoring_disabled': 'bool',
            'is_management_disabled': 'bool',
            'are_all_plugins_disabled': 'bool',
            'plugins_config': 'list[InstanceAgentPluginConfigDetails]'
        }

        self.attribute_map = {
            'is_monitoring_disabled': 'isMonitoringDisabled',
            'is_management_disabled': 'isManagementDisabled',
            'are_all_plugins_disabled': 'areAllPluginsDisabled',
            'plugins_config': 'pluginsConfig'
        }

        self._is_monitoring_disabled = None
        self._is_management_disabled = None
        self._are_all_plugins_disabled = None
        self._plugins_config = None

    @property
    def is_monitoring_disabled(self):
        """
        Gets the is_monitoring_disabled of this UpdateInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can gather performance metrics and monitor the instance using the
        monitoring plugins.

        These are the monitoring plugins: Compute Instance Monitoring
        and Custom Logs Monitoring.

        The monitoring plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isMonitoringDisabled` is true, all of the monitoring plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isMonitoringDisabled` is false, all of the monitoring plugins are enabled. You
        can optionally disable individual monitoring plugins by providing a value in the `pluginsConfig`
        object.


        :return: The is_monitoring_disabled of this UpdateInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._is_monitoring_disabled

    @is_monitoring_disabled.setter
    def is_monitoring_disabled(self, is_monitoring_disabled):
        """
        Sets the is_monitoring_disabled of this UpdateInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can gather performance metrics and monitor the instance using the
        monitoring plugins.

        These are the monitoring plugins: Compute Instance Monitoring
        and Custom Logs Monitoring.

        The monitoring plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isMonitoringDisabled` is true, all of the monitoring plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isMonitoringDisabled` is false, all of the monitoring plugins are enabled. You
        can optionally disable individual monitoring plugins by providing a value in the `pluginsConfig`
        object.


        :param is_monitoring_disabled: The is_monitoring_disabled of this UpdateInstanceAgentConfigDetails.
        :type: bool
        """
        self._is_monitoring_disabled = is_monitoring_disabled

    @property
    def is_management_disabled(self):
        """
        Gets the is_management_disabled of this UpdateInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available management plugins.

        These are the management plugins: OS Management Service Agent and Compute Instance
        Run Command.

        The management plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isManagementDisabled` is true, all of the management plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isManagementDisabled` is false, all of the management plugins are enabled. You
        can optionally disable individual management plugins by providing a value in the `pluginsConfig`
        object.


        :return: The is_management_disabled of this UpdateInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._is_management_disabled

    @is_management_disabled.setter
    def is_management_disabled(self, is_management_disabled):
        """
        Sets the is_management_disabled of this UpdateInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available management plugins.

        These are the management plugins: OS Management Service Agent and Compute Instance
        Run Command.

        The management plugins are controlled by this parameter and by the per-plugin
        configuration in the `pluginsConfig` object.

        - If `isManagementDisabled` is true, all of the management plugins are disabled, regardless of
        the per-plugin configuration.
        - If `isManagementDisabled` is false, all of the management plugins are enabled. You
        can optionally disable individual management plugins by providing a value in the `pluginsConfig`
        object.


        :param is_management_disabled: The is_management_disabled of this UpdateInstanceAgentConfigDetails.
        :type: bool
        """
        self._is_management_disabled = is_management_disabled

    @property
    def are_all_plugins_disabled(self):
        """
        Gets the are_all_plugins_disabled of this UpdateInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available plugins.
        This includes the management and monitoring plugins.

        To get a list of available plugins, use the
        :func:`list_instanceagent_available_plugins`
        operation in the Oracle Cloud Agent API. For more information about the available plugins, see
        `Managing Plugins with Oracle Cloud Agent`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/manage-plugins.htm


        :return: The are_all_plugins_disabled of this UpdateInstanceAgentConfigDetails.
        :rtype: bool
        """
        return self._are_all_plugins_disabled

    @are_all_plugins_disabled.setter
    def are_all_plugins_disabled(self, are_all_plugins_disabled):
        """
        Sets the are_all_plugins_disabled of this UpdateInstanceAgentConfigDetails.
        Whether Oracle Cloud Agent can run all the available plugins.
        This includes the management and monitoring plugins.

        To get a list of available plugins, use the
        :func:`list_instanceagent_available_plugins`
        operation in the Oracle Cloud Agent API. For more information about the available plugins, see
        `Managing Plugins with Oracle Cloud Agent`__.

        __ https://docs.cloud.oracle.com/iaas/Content/Compute/Tasks/manage-plugins.htm


        :param are_all_plugins_disabled: The are_all_plugins_disabled of this UpdateInstanceAgentConfigDetails.
        :type: bool
        """
        self._are_all_plugins_disabled = are_all_plugins_disabled

    @property
    def plugins_config(self):
        """
        Gets the plugins_config of this UpdateInstanceAgentConfigDetails.
        The configuration of plugins associated with this instance.


        :return: The plugins_config of this UpdateInstanceAgentConfigDetails.
        :rtype: list[oci.core.models.InstanceAgentPluginConfigDetails]
        """
        return self._plugins_config

    @plugins_config.setter
    def plugins_config(self, plugins_config):
        """
        Sets the plugins_config of this UpdateInstanceAgentConfigDetails.
        The configuration of plugins associated with this instance.


        :param plugins_config: The plugins_config of this UpdateInstanceAgentConfigDetails.
        :type: list[oci.core.models.InstanceAgentPluginConfigDetails]
        """
        self._plugins_config = plugins_config

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ReplicaDetails(object):
    """
    Details of replication status
    """

    #: A constant which can be used with the status property of a ReplicaDetails.
    #: This constant has a value of "REPLICATING"
    STATUS_REPLICATING = "REPLICATING"

    #: A constant which can be used with the status property of a ReplicaDetails.
    #: This constant has a value of "REPLICATED"
    STATUS_REPLICATED = "REPLICATED"

    def __init__(self, **kwargs):
        """
        Initializes a new ReplicaDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param region:
            The value to assign to the region property of this ReplicaDetails.
        :type region: str

        :param status:
            The value to assign to the status property of this ReplicaDetails.
            Allowed values for this property are: "REPLICATING", "REPLICATED", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type status: str

        """
        self.swagger_types = {
            'region': 'str',
            'status': 'str'
        }

        self.attribute_map = {
            'region': 'region',
            'status': 'status'
        }

        self._region = None
        self._status = None

    @property
    def region(self):
        """
        Gets the region of this ReplicaDetails.
        The replica region


        :return: The region of this ReplicaDetails.
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """
        Sets the region of this ReplicaDetails.
        The replica region


        :param region: The region of this ReplicaDetails.
        :type: str
        """
        self._region = region

    @property
    def status(self):
        """
        Gets the status of this ReplicaDetails.
        Replication status associated with a replicationId

        Allowed values for this property are: "REPLICATING", "REPLICATED", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The status of this ReplicaDetails.
        :rtype: str
        """
        return self._status

    @status.setter
    def status(self, status):
        """
        Sets the status of this ReplicaDetails.
        Replication status associated with a replicationId


        :param status: The status of this ReplicaDetails.
        :type: str
        """
        allowed_values = ["REPLICATING", "REPLICATED"]
        if not value_allowed_none_or_none_sentinel(status, allowed_values):
            status = 'UNKNOWN_ENUM_VALUE'
        self._status = status

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
